NetPrimitivesFor

Trait NetPrimitivesFor 

pub trait NetPrimitivesFor<N: NodePrimitives>: NetworkPrimitives<BlockHeader = N::BlockHeader, BlockBody = N::BlockBody, Block = N::Block, Receipt = N::Receipt> { }
This is a helper trait for use in bounds, where some of the NetworkPrimitives associated types must be the same as the [NodePrimitives] associated types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<N, T> NetPrimitivesFor<N> for T
where N: NodePrimitives, T: NetworkPrimitives<BlockHeader = N::BlockHeader, BlockBody = N::BlockBody, Block = N::Block, Receipt = N::Receipt>,